// @ts-nocheck
/**
 * @file        主应用接口自动化测试（Elysia fetch版）
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 覆盖健康检查、登录、受保护接口的集成测试，直接调用app.fetch
 */

import { describe, it, expect } from 'vitest';
import { app } from './app';

let token = '';

/**
 * 健康检查接口测试
 */
describe('GET /api/health', () => {
    it('应返回服务运行正常', async () => {
        const res = await app.fetch(new Request('http://localhost/api/health'));
        const body = await res.json();
        expect(res.status).toBe(200);
        expect(body.code).toBe(0);
        expect(body.message).toBe('服务运行正常');
    });
});

/**
 * 登录接口测试
 */
describe('POST /api/login', () => {
    it('应登录成功并返回token', async () => {
        const res = await app.fetch(
            new Request('http://localhost/api/login', {
                method: 'POST',
                headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify({ username: 'admin', password: '123456' }),
            }),
        );
        const body = await res.json();
        expect(res.status).toBe(200);
        expect(body.code).toBe(0);
        expect(typeof body.data.token).toBe('string');
        token = body.data.token;
    });

    it('用户名或密码错误应返回400', async () => {
        const res = await app.fetch(
            new Request('http://localhost/api/login', {
                method: 'POST',
                headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify({ username: 'admin', password: 'wrong6' }),
            }),
        );
        const body = await res.json();
        expect(res.status).toBe(400);
        expect(body.code).toBe(400);
        expect(body.message).toBe('用户名或密码错误');
    });
});

/**
 * 受保护接口测试
 */
describe('GET /api/protected', () => {
    it('无Token应返回401', async () => {
        const res = await app.fetch(new Request('http://localhost/api/protected'));
        const body = await res.json();
        expect(res.status).toBe(401);
        expect(body.code).toBe(401);
    });

    it('Token错误应返回401', async () => {
        const res = await app.fetch(
            new Request('http://localhost/api/protected', {
                headers: { Authorization: 'Bearer wrongtoken' },
            }),
        );
        const body = await res.json();
        expect(res.status).toBe(401);
        expect(body.code).toBe(401);
    });

    it('Token正确应返回用户信息', async () => {
        const res = await app.fetch(
            new Request('http://localhost/api/protected', {
                headers: { Authorization: `Bearer ${token}` },
            }),
        );
        const body = await res.json();
        expect(res.status).toBe(200);
        expect(body.code).toBe(0);
        expect(body.data.username).toBe('admin');
    });
});
